@@ -5,7 +5,7 @@ import itertools as it, operator as op, functools as ft
 
 from datetime import datetime, timedelta
 from posixpath import join as ujoin # used for url pahs
-from os.path import join, basename, exists
+from os.path import join, basename, dirname, exists
 import os, sys, io, urllib, urlparse, json, types, re
 
 from onedrive.conf import ConfigMixin
@@ -101,7 +101,8 @@ class OneDriveHTTPClient(object):
 			log.warn( 'Not using request_adapter_settings, as these should not be'
 				' supported by detected requests module version: %s', requests_version )
 
-		if hasattr(sys, '_MEIPASS'): # fix cacert.pem path for running from PyInstaller bundle
+		if hasattr(sys, '_MEIPASS'):
+			# Fix cacert.pem path for running from PyInstaller bundle
 			cacert_pem = requests.certs.where()
 			if not exists(cacert_pem):
 				from pkg_resources import resource_filename
@@ -118,6 +119,29 @@ class OneDriveHTTPClient(object):
 			log.debug( 'Adjusted "requests" default ca-bundle'
 				' path (to run under PyInstaller) to: %s', cacert_pem )
 
+		if requests_version >= (2, 4, 0):
+			# Workaround for https://github.com/certifi/python-certifi/issues/26
+			import ssl
+			if ssl.OPENSSL_VERSION_INFO < (1, 0, 2):
+				try: import certifi
+				except ImportError: pass
+				else:
+					certifi_issue_url = 'https://github.com/certifi/python-certifi/issues/26'
+					if hasattr(certifi, 'old_where'): cacert_pem = certifi.old_where()
+					else:
+						cacert_pem = join(dirname(requests.certs.__file__), 'cacert.pem')
+						if not exists(cacert_pem):
+							cacert_pem = None
+							log.warn( 'Failed to find requests'
+								' certificate bundle for woraround to %s', certifi_issue_url )
+					if cacert_pem:
+						self._requests_base_keywords = (self._requests_base_keywords or dict()).copy()
+						self._requests_base_keywords.setdefault('verify', cacert_pem)
+						log.debug( 'Adjusted "requests" default ca-bundle path, to work around %s '
+							' [OpenSSL version %s, requests %s (>2.4.0) and certifi available at %r], to: %s',
+							certifi_issue_url, ssl.OPENSSL_VERSION_INFO,
+							requests_version, certifi.__file__, cacert_pem )
+
 		self._requests_setup_done = True
 		return session
 
@@ -338,6 +362,7 @@ class OneDriveAPIWrapper(OneDriveAuth):
 		name, src = (basename(path_or_tuple), open(path_or_tuple, 'rb'))\
 			if isinstance(path_or_tuple, types.StringTypes)\
 			else (path_or_tuple[0], path_or_tuple[1])
+		if isinstance(src, types.StringTypes): src = io.BytesIO(src)
 		return name, src
 
 	def _translate_api_flag(self, val, name=None, special_vals=None):
@@ -510,10 +535,11 @@ class OneDriveAPIWrapper(OneDriveAuth):
 		h = lambda k,hs=dict((k.lower(), v) for k,v in headers.viewitems()): hs.get(k, '')
 		checks = [ code == 201,
 			h('bits-packet-type').lower() == 'ack',
-			h('bits-protocol').lower() == self.api_bits_protocol_id.lower() ]
+			h('bits-protocol').lower() == self.api_bits_protocol_id.lower(),
+			h('bits-session-id') ]
 		if not all(checks):
 			raise ProtocolError(code, 'Invalid BITS Create-Session response', headers, body, checks)
-		bits_sid = headers['bits-session-id']
+		bits_sid = h('bits-session-id')
 
 		src.seek(0, os.SEEK_END)
 		c, src_len = 0, src.tell()
@@ -536,8 +562,9 @@ class OneDriveAPIWrapper(OneDriveAuth):
 
 			if chunk_callback:
 				chunk_callback(
-					bytes_uploaded=c, bytes_count=src_len,
-					chunk_n=n, chunk_count=cn, bits_session_id=bits_sid )
+					bytes_transferred=c, bytes_total=src_len,
+					chunks_transferred=n, chunks_total=cn,
+					bits_session_id=bits_sid )
 
 		if self.api_bits_auth_refresh_before_commit_hack:
 			# As per #39 and comments under the gist with the spec,
